@@ -181,8 +181,8 @@ class AeroProfile:
       except TypeError:
         raise ParameterError("Aerosol Distribution Imaginary Refractive Index", "You must specify the imaginary part of the Refractive Index at 20 wavelengths.")
 
-      real = map(str, refr_real)
-      imag = map(str, refr_imag)
+      real = list(map(str, refr_real))
+      imag = list(map(str, refr_imag))
       comp += ' '.join(real) + '\n'
       comp += ' '.join(imag) + '\n'
       
@@ -247,8 +247,8 @@ class AeroProfile:
           raise ParameterError("Aerosol Distribution Imaginary Refractive Index", "You must specify the imaginary part of the Refractive Index at 20 wavelengths.")
         
         comp = "%f %f %f\n" % (rmean, sigma, percentage_density)
-        real = map(str, refr_real)
-        imag = map(str, refr_imag)
+        real = list(map(str, refr_real))
+        imag = list(map(str, refr_imag))
         comp += ' '.join(real) + '\n'
         comp += ' '.join(imag) + '\n'
         
