@@ -17,9 +17,14 @@
 
 from Py6S import *
 import numpy as np
-import urllib
+
+try:
+  from urllib.request import urlopen
+except:
+  from urllib import urlopen
+
 import re
-import StringIO
+import io
 from scipy.interpolate import interp1d
 
 
@@ -290,7 +295,7 @@ class Radiosonde:
     
     """
     # Get data from given URL
-    u = urllib.urlopen(url)
+    u = urlopen(url)
     
     if u.getcode() != 200:
       # We have't got the HTTP OK status code, so something is wrong (like the URL is invalid)
@@ -298,21 +303,21 @@ class Radiosonde:
     
     html = u.read()
     
-    if "Sorry, the server is too busy to process your request" in html:
+    if b"Sorry, the server is too busy to process your request" in html:
       raise ParameterException("url", "The server is too busy")
 
     # Extract the data inside the PRE tag (we can do it like this because it is very simple HTML)
-    regex = re.compile("<PRE>(.*?)</PRE>",re.IGNORECASE|re.DOTALL)
+    regex = re.compile(b"<PRE>(.*?)</PRE>",re.IGNORECASE|re.DOTALL)
     r = regex.search(html)
     table = r.groups()[0].strip()
     
     # Remove last line as it is normally incomplete
-    spl = table.split("\n")
+    spl = table.split(b"\n")
     spl = spl[:-1]
-    table = "\n".join(spl)
+    table = b"\n".join(spl)
     
     # Import to NumPy arrays
-    s = StringIO.StringIO(table)
+    s = io.BytesIO(table)
     array = np.loadtxt(s, skiprows=4, usecols=(0, 1, 2, 5))
     
     pressure = array[:,0]
