@@ -1,5 +1,22 @@
-import sixs
-from Params import *
+# This file is part of Py6S.
+#
+# Copyright 2012 Robin Wilson and contributors listed in the CONTRIBUTORS file.
+#
+# Py6S is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Py6S is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with Py6S.  If not, see <http://www.gnu.org/licenses/>.
+
+from . import sixs
+from .Params import *
 from pylab import *
 import numpy as np
 
@@ -18,7 +35,7 @@ def all_angles(s):
       #values.append(s.outputs.pixel_reflectance)
       d = dict(s.outputs.values)
       values.append(d)
-      print "%i %i %f" % (azimuth, zenith, d['pixel_reflectance'])
+      print(("%i %i %f" % (azimuth, zenith, d['pixel_reflectance'])))
       
   return values
   
